vzense-sys
Generates and uses Vzense C library bindings as a Rust crate. This crate is used as a base layer in vzense-rust.
Structs
- @brief Color image pixel type in 24-bit BGR format.
- @brief Specifies the camera’s location and orientation extrinsic parameters.
- @brief Camera intrinsic parameters and distortion coefficients.
- @brief Contains depth information for a given pixel.
- @brief Depth/IR/RGB image frame data.
- @brief Specifies the frame mode including the pixel format, resolution, and frame rate.
- @brief Specifies the GMMGain including the gain value and option type.
- @brief Color image pixel type in 24-bit RGB format.
- @brief Stores the x, y, and z components of a 2D vector.
- @brief Stores the x, y, and z components of a 3D vector.
- @brief WDR (Wide Dynamic Range) output mode settings (e.g. Near/Far range fusion).
- @brief WDR (Wide Dynamic Range) output mode settings (e.g. Near/Far range fusion).
- @brief WDR (Wide Dynamic Range) output mode settings (e.g. Near/Far range fusion).
Constants
- !< Outputs both depth and IR frames and RGB frame at 30 fps. The resolution for both depth and IR frames is 640480.\n !< The resolution of and RGB frame can be set using ::PsSetFrameMode(), which supports 16001200/800600/640480.
- !< Output both depth and RGB frames at 30 fps. The resolution of a depth frame is 640480.\n !< The resolution of an RGB frame can be set using ::PsSetFrameMode(), which supports 16001200/800600/640480.
- !< Outputs both IR and RGB frames at 30 fps. The resolution of an IR frame is 640480.\n !< The resolution of and RGB frame can be set using ::PsSetFrameMode(), which supports 16001200/800600/640480.
- !< Reserved for internal use.
- !< WDR (Wide Dynamic Range) depth mode. Supports alternating multi-range depth frame output (e.g. Near/Far/Near/Far/Near).
- !< WDR (Wide Dynamic Range) Depth and IR mode. Not currently implemented.
- !< WDR (Wide Dynamic Range) IR mode. Not currently implemented.
- !< Depth frame with 16 bits per pixel in millimeters.
- !< IR frame with 16 bits per pixel.
- !< Depth frame with 16 bits per pixel, in millimeters, that is mapped to RGB camera space where the resolution is same as the RGB frame’s resolution.\n !< This frame type can be enabled using ::PsSetMapperEnabledRGBToDepth().
- !< RGB frame with 24 bits per pixel in RGB/BGR format, that is mapped to depth camera space where the resolution is the same as the depth frame’s resolution.\n !< This frame type can be enabled using ::PsSetMapperEnabledDepthToRGB().
- !< RGB frame with 24 bits per pixel in RGB/BGR format.
- !< WDR depth frame with 16 bits per pixel in millimeters. This only takes effect when the data mode set to ::PsWDR_Depth.
- !< Color image pixel format, 24 bits per pixel BGR format.
- !< Depth image pixel format, 16 bits per pixel in mm.
- !< Gray image pixel format, 8 bits per pixel.
- !< IR image pixel format, 16 bits per pixel.
- !< Color image pixel format, 24 bits per pixel RGB format.
- !< Gets the data mode lists that the device support
- !< Gets the depth range lists that the device support
- !< The camera has not been opened.
- !< The camera has been opened.
- !< Set/Get cmd control error
- !< Set cmd ok.but time out for the sync return
- !< This feature is not supported in the current version.
- !< The device structure pointer is null.
- !< The output frame buffer is null.
- !< IP is not in the same network segment
- !< An input pointer parameter is null.
- !< The specified type of camera is invalid.
- !< The input depth range mode is invalid.
- !< The input device index is invalid.
- !< The input frame type is invalid.
- !< One or more of the parameter values provided are invalid.
- !< There is no adapter connected
- !< There is no depth camera connected or the camera has not been connected correctly. Check the hardware connection or try unplugging and re-plugging the USB cable.
- !< The SDK has bot been Initialized
- !< Cannot get the value for the specified property.
- !< Cannot set the value for the specified property.
- !< The function completed successfully.
- !< An unknown error occurred.
- !< The input property value buffer pointer is null.
- !< The input property value buffer size is too small to store the specified property value.
- !< The SDK has been Initialized
- !< Capture the next image frame time out.
- !< Ps2_SetUpgradeStatusCallback is not called.
- !< There is an error in the upgrade file.
- !< Upgrade file path length greater than 260.
- !< Depth camera.
- !< Color (RGB) camera.
- !< Depth Stream
- !< IR Stream
- !< RGB Stream
- !< WDR image output alternates between depths (e.g. Near/Far/Near/Far … ).
- !< WDR image output is fused from multiple ranges.
- !< Three depth ranges.
- !< Two depth ranges.
Functions
- @brief Closes the device specified by
devicethat was opened using PsOpenDevice. @param[in] device The handle of the device to close. @return: ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Converts the input Depth frame from depth coordinate space to world coordinate space on the device. @param[in] device The handle of the device on which to perform the operation. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] depthFrame The depth frame. @param[out] pWorldVector Pointer to a buffer in which to output the converted x, y, and z values of the world coordinates, measured in millimeters. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Converts the input points from depth coordinate space to world coordinate space. @param[in] device The handle of the device on which to perform the operation. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pDepthVector Pointer to a buffer containing the x, y, and z values of the depth coordinates to be converted. \n x and y are measured in pixels, where 0, 0 is located at the top left corner of the image. \n z is measured in millimeters, based on the ::PsPixelFormat depth frame. @param[out] pWorldVector Pointer to a buffer in which to output the converted x, y, and z values of the world coordinates, measured in millimeters. @param[in] pointCount The number of points to convert. @param[in] pCameraParam The intrinsic camera parameters for the depth camera. See ::PsGetCameraParameters. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Converts the input points from world coordinate space to depth coordinate space. @param[in] device The handle of the device on which to perform the operation. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pWorldVector Pointer to a buffer containing the x, y, and z values of the input world coordinates to be converted, measured in millimeters. @param[out] pDepthVector Pointer to a buffer in which to output the converted x, y, and z values of the depth coordinates. \n x and y are measured in pixels, where 0, 0 is located at the top left corner of the image. \n z is measured in millimeters, based on the ::PsPixelFormat depth frame. @param[in] pointCount The number of coordinates to convert. @param[in] pCameraParam The intrinsic camera parameters for the depth camera. See ::PsGetCameraParameters. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the camera rotation and translation coefficient parameters from the device specified by
device. @param[in] device The handle of the device from which to get the extrinsic parameters. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pCameraExtrinsicParameters Pointer to a ::PsGetCameraExtrinsicParameters variable in which to store the parameters. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the internal intrinsic and distortion coefficient parameters from the device specified by
device. @param[in] device The handle of the device from which to get the internal parameters. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] sensorType The type of sensor (depth or RGB) from which to get parameter information. Pass in the applicable value defined by ::PsSensorType. @param[out] pCameraParameters Pointer to a PsCameraParameters variable in which to store the parameter values. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the Boolean value of whether the ComputeRealDepth feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the Boolean value of whether the ConfidenceFilter feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the ConfidenceFilter threshold value for the device specified by
device. @param[in] device The handle of the device on which to set the threshold. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] threshold The threshold value to set. 0 will attempt to keep all point data but may not be accurate further away; 1000 is the max value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the Boolean value of whether the DSP feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the output data mode from the device specified by
device. @param[in] device The handle of the device for which to set the data mode. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[Out] dataMode The output data mode. See ::PsDataMode for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the Boolean value of whether the depth and ir distortion correction feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the depth range mode from the device specified by
device. @param[in] device The handle of the device from which to get the depth range. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pDepthRange Pointer to a ::PsDepthRange variable in which to store the returned depth range mode. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the number of camera devices currently connected. @param[out] pDeviceCount Pointer to a 32-bit integer variable in which to return the device count. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets IP from the device specified by
uri. @param[in] uri the uri of the device. See ::PsDeviceInfo for more information. @param[out] ip Pointer to a buffer in which to store the device IP. the buffer default size is 17, and the last buffer set ‘\0’. @return: ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the info of the deviceIndex camera device. @param[in] deviceIndex The index of the device to open. Device indices range from 0 to device count - 1. @param[out] pDevices Pointer to a buffer in which to store the device info. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the info lists of the deviceCount camera devices. @param[in] deviceCount the number of camera devices. @param[out] pDevicesList Pointer to a buffer in which to store the deviceCount devices infos. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the MAC from the device specified by
device. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[out] mac Pointer to a buffer in which to store the device MAC. the buffer default size is 18, and the last buffer set ‘\0’. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Gets the firmware version number. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] fw Pointer to a variable in which to store the returned fw value. @param[in] length The maximum length is 63 bytes. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the image data for the current frame from the device specified by
device.\n Before invoking this API, invoke PsReadNextFrame() to capture one image frame from the device. @param[in] device The handle of the device to capture an image frame from. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] frameType The image frame type. @param[out] pPsFrame Pointer to a buffer in which to store the returned image data. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the the device’s GMM gain. @param[in] device The handle of the device from which to get the GMM gain. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] gmmgain Pointer to a variable in which to store the returned GMM gain. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the point value of the frame that the mapping of the depth image to RGB space. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pointInDepth The point in depth frame. @param[in] rgbSize The size(x = w,y = h) of rgb frame.
- @brief Returns the Boolean value of whether the mapping of the depth image to RGB space feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the Boolean value of whether the mapping of the RGB image to depth space feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the MeasuringRange in depthRange. @param[in] device The handle of the device on which to set the WDR style. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] depthRange Specifies the depth range mode. @param[out] pMeasuringRange A pointer to a ::PsMeasuringRange variable in which to store the MeasuringRange in depthRange. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns a specific property value from the device specified by
device. @param[in] device The handle of the device from which to get the property value. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] propertyType The type of property to get from the device. See ::PsPropertyType for more information. @param[out] pData Pointer to a buffer to store the returned property value. @param[out] pDataSize The size, in bytes, of the property value returned inpData. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the pulse count from the device specified by
device. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pPulseCount Pointer to a 16-bit unsigned integer variable in which to store the pulse count value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Gets the RGB absolute exposure in manual. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[out] value The value of brightness,in [1,4000] and the unit is 100us. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the RGB brightness. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[out] value The value of brightness,in [-64,64]. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the Boolean value of whether the RGB distortion correction feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the RGB frequency of power line. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[out] value The frequency value of power line, 1:50HZ 2:60HZ @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the Boolean value of whether the RGB manual exposure feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the maximum exposure time of RGB in AEC. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[out] value The value of brightness,in [1,30] and the unit is 1ms. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the the RGB frame Resolution. @param[in] device The handle of the device from which to get the GMM gain. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] resolution Pointer to a variable in which to store the returned resolution. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the version of SDK. @param[in] version Pointer to a variable in which to store the returned version value. @param[in] length The maximum length is 63 bytes. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the serial number. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] sn Pointer to a variable in which to store the returned sn value. @param[in] length The maximum length is 63 bytes. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the Boolean value of whether the SpatialFilter feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the Boolean value of whether the syncronize feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the threshold value for the background filter from the device specified by
device. \n The value represents the cut-off point for distant data that the filter should ignore. \n For example, if 20.0 is specified, data with 20% or less confidence will be dropped. @param[in] device The handle of the device from which to get the threshold. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pThreshold Pointer to a 16-bit unsigned integer variable in which to return the threshold value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Returns the Boolean value of whether the TimeFilter feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the tof frame rate. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] value The rate value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Gets the WDR ConfidenceFilter threshold value for the device specified by
device. @param[in] device The handle of the device on which to set the threshold. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] threshold The threshold value to set. 0 will attempt to keep all point data but may not be accurate further away; 1000 is the max value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Gets the current WDR output mode. @param[in] device The handle of the device on which to get the mode from. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pWDRMode A pointer to a ::PsWDROutputMode variable in which to store the current WDR output mode. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Returns the pulse count from the device specified by
device. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pwdrPulseCount A pointer to a ::PsWDRPulseCount variable in which to store the PulseCount in WDR mode. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Initializes the API on the device. This function must be invoked before any other Vzense APIs. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Opens the device specified by
uri. The device must be subsequently closed using PsCloseDevice(). @param[in] uri the uri of the device. See ::PsDeviceInfo for more information. @param[out] pDevices the handle of the device on which to open. @return: ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Opens the device specified by
alias. The device must be subsequently closed using PsCloseDevice(). @param[in] alias the alias of the device. See ::PsDeviceInfo for more information. @param[out] pDevices the handle of the device on which to open. @return: ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Opens the device specified by
ip. The device must be subsequently closed using PsCloseDevice(). @param[in] ip the ip of the device. See ::PsDeviceInfo for more information. @param[out] pDevices the handle of the device on which to open. @return: ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Captures the next image frame from the device specified by
device. This API must be invoked before capturing frame data using PsGetFrame(). @param[in] device The handle of the device on which to read the next frame. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pFrameReady Pointer to a buffer in which to store the signal on which image is ready to be get. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Reboot the camera. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets the color image pixel format on the device specified by
device. Currently only RGB and BGR formats are supported. @param[in] device The handle of the device to set the pixel format. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pixelFormat The color pixel format to use. Pass in one of the values defined by ::PsPixelFormat. Currently onlyPsPixelFormatRGB888andPsPixelFormatBGR888are supported. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the ComputeRealDepth feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the ConfidenceFilter feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the ConfidenceFilter threshold value for the device specified by
device. @param[in] device The handle of the device on which to set the threshold. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] threshold The threshold value to set. 0 will attempt to keep all point data but may not be accurate further away; 1000 is the max value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the DSP feature for tof frame. The DSP feature only support ComputeRealDepthCorrection and SpatialFilter. The default filter has ComputeRealDepthCorrection, SpatialFilter,TimeFilter, DepthDistortionCorrection and IrDistortionCorrection. Enable the DSP feature can reduce SDK loading, but disable it has a better effect. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the output data mode for the device specified by
device. @param[in] device The handle of the device for which to set the data mode. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] dataMode The output data mode. See ::PsDataMode for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the depth and ir distortion correction feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the Depth Stream feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the depth range mode for the device specified by
device. @param[in] device The handle of the device on which to set the depth range. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] depthRange Specifies the depth range mode. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the device GMM gain on a device. @param[in] device The handle of the device on which to set the GMM gain. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] gmmgain The GMM gain value to set. See ::PsGMMGain for more information.The GMM gain value is in the range [0,4095]. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets hotplug status callback function @param[in] pCallback Pointer to the callback function. See ::PtrHotPlugStatusCallback @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets hotplug status callback function for c plus plus @param[in] pCallback Pointer to the callback function. See ::PtrHotPlugStatusCallback @param[in] contex Pointer to the object of C++ class @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets the ImageMirror feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] type 1 left-right mirror; 2 up-down mirror;3 both mirror (rotation 180) @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets the ImageRotation feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] type 0 counterclock 906у; 1 counterclock 1806у;2 counterclock 2706у @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Enables or disables the IR Stream feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the legacy algorithmic,and default value is disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Enables or disables mapping of the depth image to RGB space on the device. When enabled, PsGetFrame() can\n be invoked passing ::PsMappedRGBFrame as the frame type, to get the depth frame that is mapped to RGB space. The resolution of\n the mapped rgb frame is the same as that of the depth image. @param[in] device The handle of the device on which to enable or disable mapping. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables mapping of the RGB image to depth space on the device. When enabled, PsGetFrame()\n can be invoked passing ::PsMappedDepthFrame as the frame type, to get the RGB frame that is mapped to depth space. The resolution\n of the mapped depth frame is the same as that of the RGB image. @param[in] device The handle of the device on which to enable or disable mapping. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Set the corresponding property value for the device specified by
device. @param[in] device The handle of the device from which to set the property value. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] propertyType The type of property to set on the device. @param[in] pData Pointer to a buffer containing the property value. @param[in] dataSize The size, in bytes, of the property value contained inpData. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the pulse count for the device specified by
device. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pulseCount The pulse count value to set.For the range 3 and 4,the value is in the range [0,260],for the other range,the value is in the range [0,600]. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the RGB absolute exposure in manual. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[in] value The value of brightness,in [1,4000] and the unit is 100us. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets the RGB brightness. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[in] value The value of brightness,in [-64,64]. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Enables or disables the RGB distortion correction feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the RGB frequency of power line. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[in] value The frequency value of power line, 1:50HZ 2:60HZ @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Enables or disables the RGB manual exposure feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the maximum exposure time of RGB in AEC. @param[in] device The handle of the device. @param[in] sessionIndex The index of the session. @param[in] value The value of brightness,in [1,30] and the unit is 1ms. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets the RGB frame Resolution. @param[in] device The handle of the device on which to set the GMM gain. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] resolution The resolution value to set. See ::PsResolution for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Enables or disables the RGB Stream feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Trigger frame data once in slave mode. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Enables or disables the SpatialFilter feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the StandBy feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the syncronize feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the threshold value for the background filter for the device specified by
device. \n The value represents the cut-off point for distant data that the filter should ignore. \n For example, if 20.0 is specified, data with 20% or less confidence will be dropped. @param[in] device The handle of the device on which to set the threshold. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] threshold The threshold value to set. 0 will attempt to keep all point data but may not be accurate further away; 100 or higher will reject almost all point data leaving only the closest points. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Enables or disables the TimeFilter feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to
trueto enable the feature orfalseto disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the tof frame rate. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] value The value of rate,in 3,5,6,10,15,30. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets the WDR ConfidenceFilter threshold value for the device specified by
device. @param[in] device The handle of the device on which to set the threshold. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] threshold The threshold value to set. 0 will attempt to keep all point data but may not be accurate further away; 1000 is the max value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the WDR output mode. @param[in] device The handle of the device on which to set the mode. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pWDRMode The WDR output mode to set. See ::PsWDROutputMode for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Sets the pulse count for the device specified by
device. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pwdrPulseCount The PulseCount value in WDR mode to set. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Sets the WDR style on the device. @param[in] device The handle of the device on which to set the WDR style. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] wdrStyle The wide dynamic range merge style to use. See ::PsWDRStyle for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Set the waittime of read next frame. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] time The unit is millisecond, the value is in the range (0,65535) and the default value is 350 millisecond. You can change the value according to the frame rate. For example,the frame rate is 30, so the theoretical waittime interval is 33ms, but if set the time value is 20ms, it means the max wait time is 20 ms when capturing next frame, so when call the Ps2_ReadNextFrame, it may return PsRetReadNextFrameTimeOut(-11). so the value range that recommended is [50.350]. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Shuts down the API on the device and clears all resources allocated by the API. After invoking this function, no other Vzense APIs can be invoked. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
- @brief Starts capturing the image stream indicated by
device. \n Invoke Ps2_StopStream() to stop capturing the image stream. @param[in] device The handle of the device on which to start capturing the image stream. @param[in] sessionIndex The index of the session that include N Tof sensors and maximum N RGB sensors. \n range from 0 to ::SessionCount - 1. See ::PsDeviceInfo for more information. \n For example, the cameradevicehas 2 Tof sensor and 1 rgb sensor, the ::SessionCount is 2.\n If thesessionIndexis 0 mean that start 1 tof stream and the rgb stream, \n and if thesessionIndexis 1 mean that start only 1 tof stream. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus. - @brief Stops capturing the image stream on the device specified by
device. that was started using Ps2_StartStream. @param[in] device The handle of the device on which to stop capturing the image stream. @param[in] sessionIndex The index of the session that include N Tof sensors and maximum N RGB sensors. \n range from 0 to ::SessionCount - 1. See ::PsDeviceInfo for more information. \n For example, the cameradevicehas 2 Tof sensor and 1 rgb sensor, the ::SessionCount is 2.\n If thesessionIndexis 0 mean that stop 1 tof stream and the rgb stream, \n and if thesessionIndexis 1 mean that stop only 1 tof stream. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.
Type Aliases
- @brief The data modes that determine the frame output from the device and the frame rate (fps).
- @brief Depth range setting.\n These set estimated ranges. Detection distances may be greater than what is listed for the given setting. \n Precision and minimum distance for depth detection varies with longer ranges.
- @brief Specifies the type of image frame.
- @brief Specifies the image pixel format.
- @brief Camera device properties to get or set on a device.
- @brief Resolution
- @brief Return status codes for all APIs.\n
PsRetOK = 0means the API successfully completed its operation.\n All other codes indicate a device, parameter, or API usage error. - @brief Specifies the type of camera sensor.
- @brief Stream type
- @brief The WDR style setting used for ::PsSetWDRStyle(). This determines if the WDR image output is a fusion from multiple ranges (e.g. Near/Far fusion)\n or an alternative output (e.g. Near/Far/Near/Far … ).
- @brief Specifies the number of depth ranges defined for WDR. Currently only two or three ranges are supported (e.g. Near/Far or Near/Mid/Far).
- @brief hotplug status callback function pInfo return the info of the Device, See ::PsDeviceInfo state 0:device added , 1:device removed
- @brief hotplug status callback function for c plus plus pInfo return the info of the Device, See ::PsDeviceInfo state 0:device added , 1:device removed contex pointer to the object of C++ class