Ps2_SetColorPixelFormat

Function Ps2_SetColorPixelFormat 

pub unsafe extern "C" fn Ps2_SetColorPixelFormat(
    device: PsDeviceHandle,
    sessionIndex: u32,
    pixelFormat: PsPixelFormat,
) -> PsReturnStatus
@brief Sets the color image pixel format on the device specified by device. Currently only RGB and BGR formats are supported. @param[in] device The handle of the device to set the pixel format. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pixelFormat The color pixel format to use. Pass in one of the values defined by ::PsPixelFormat. Currently only PsPixelFormatRGB888 and PsPixelFormatBGR888 are supported. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.