Ps2_SetRGBResolution

Function Ps2_SetRGBResolution 

pub unsafe extern "C" fn Ps2_SetRGBResolution(
    device: PsDeviceHandle,
    sessionIndex: u32,
    resolution: PsResolution,
) -> PsReturnStatus
@brief Sets the RGB frame Resolution. @param[in] device The handle of the device on which to set the GMM gain. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] resolution The resolution value to set. See ::PsResolution for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.