pub unsafe extern "C" fn Ps2_SetWaitTimeOfReadNextFrame(
device: PsDeviceHandle,
sessionIndex: u32,
time: u16,
) -> PsReturnStatusExpand description
@brief Set the waittime of read next frame. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] time The unit is millisecond, the value is in the range (0,65535) and the default value is 350 millisecond. You can change the value according to the frame rate. For example,the frame rate is 30, so the theoretical waittime interval is 33ms, but if set the time value is 20ms, it means the max wait time is 20 ms when capturing next frame, so when call the Ps2_ReadNextFrame, it may return PsRetReadNextFrameTimeOut(-11). so the value range that recommended is [50.350]. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.