#[repr(C, packed(1))]pub struct PsVector3f {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
@brief Stores the x, y, and z components of a 3D vector.
Fields
x: f32!< The x, y, and z components of the vector.
y: f32!< The x, y, and z components of the vector.
z: f32!< The x, y, and z components of the vector.