PsDepthRange

Type Alias PsDepthRange 

pub type PsDepthRange = c_int;
@brief Depth range setting.\n These set estimated ranges. Detection distances may be greater than what is listed for the given setting. \n Precision and minimum distance for depth detection varies with longer ranges.