pub unsafe extern "C" fn Ps2_ConvertWorldToDepth(
device: PsDeviceHandle,
sessionIndex: u32,
pWorldVector: *mut PsVector3f,
pDepthVector: *mut PsDepthVector3,
pointCount: i32,
pCameraParam: *mut PsCameraParameters,
) -> PsReturnStatusExpand description
@brief Converts the input points from world coordinate space to depth coordinate space. @param[in] device The handle of the device on which to perform the operation. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pWorldVector Pointer to a buffer containing the x, y, and z values of the input world coordinates to be converted, measured in millimeters. @param[out] pDepthVector Pointer to a buffer in which to output the converted x, y, and z values of the depth coordinates. \n x and y are measured in pixels, where 0, 0 is located at the top left corner of the image. \n z is measured in millimeters, based on the ::PsPixelFormat depth frame. @param[in] pointCount The number of coordinates to convert. @param[in] pCameraParam The intrinsic camera parameters for the depth camera. See ::PsGetCameraParameters. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.