pub unsafe extern "C" fn Ps2_GetDeviceCount(
pDeviceCount: *mut u32,
) -> PsReturnStatusExpand description
@brief Returns the number of camera devices currently connected. @param[out] pDeviceCount Pointer to a 32-bit integer variable in which to return the device count. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.