pub unsafe extern "C" fn Ps2_GetRGBResolution(
device: PsDeviceHandle,
sessionIndex: u32,
resolution: *mut u16,
) -> PsReturnStatusExpand description
@brief Returns the the RGB frame Resolution. @param[in] device The handle of the device from which to get the GMM gain. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] resolution Pointer to a variable in which to store the returned resolution. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.