vzense_sys

Function Ps2_GetSerialNumber

source
pub unsafe extern "C" fn Ps2_GetSerialNumber(
    device: PsDeviceHandle,
    sessionIndex: u32,
    sn: *mut c_char,
    length: c_int,
) -> PsReturnStatus
@brief Gets the serial number. @param[in] device The handle of the device on which to set the pulse count. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] sn Pointer to a variable in which to store the returned sn value. @param[in] length The maximum length is 63 bytes. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.