pub unsafe extern "C" fn Ps2_GetSpatialFilterEnabled(
device: PsDeviceHandle,
sessionIndex: u32,
bEnabled: *mut u8,
) -> PsReturnStatusExpand description
@brief Returns the Boolean value of whether the SpatialFilter feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.