vzense_sys

Function Ps2_ReadNextFrame

source
pub unsafe extern "C" fn Ps2_ReadNextFrame(
    device: PsDeviceHandle,
    sessionIndex: u32,
    pFrameReady: *mut PsFrameReady,
) -> PsReturnStatus
@brief Captures the next image frame from the device specified by device. This API must be invoked before capturing frame data using PsGetFrame(). @param[in] device The handle of the device on which to read the next frame. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[out] pFrameReady Pointer to a buffer in which to store the signal on which image is ready to be get. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.