vzense_sys

Function Ps2_SetDepthRange

source
pub unsafe extern "C" fn Ps2_SetDepthRange(
    device: PsDeviceHandle,
    sessionIndex: u32,
    depthRange: PsDepthRange,
) -> PsReturnStatus
@brief Sets the depth range mode for the device specified by device. @param[in] device The handle of the device on which to set the depth range. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] depthRange Specifies the depth range mode. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.