vzense_sys

Function Ps2_SetImageRotation

source
pub unsafe extern "C" fn Ps2_SetImageRotation(
    device: PsDeviceHandle,
    sessionIndex: u32,
    type_: i32,
) -> PsReturnStatus
@brief Sets the ImageRotation feature. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] type 0 counterclock 906у; 1 counterclock 1806у;2 counterclock 2706у @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.