vzense_sys

Function Ps2_SetLegacyAlgorithmicEnabled

source
pub unsafe extern "C" fn Ps2_SetLegacyAlgorithmicEnabled(
    device: PsDeviceHandle,
    sessionIndex: u32,
    enabled: u8,
) -> PsReturnStatus
@brief Enables or disables the legacy algorithmic,and default value is disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.