vzense_sys

Function Ps2_SetMapperEnabledDepthToRGB

source
pub unsafe extern "C" fn Ps2_SetMapperEnabledDepthToRGB(
    device: PsDeviceHandle,
    sessionIndex: u32,
    bEnabled: u8,
) -> PsReturnStatus
@brief Enables or disables mapping of the depth image to RGB space on the device. When enabled, PsGetFrame() can\n be invoked passing ::PsMappedRGBFrame as the frame type, to get the depth frame that is mapped to RGB space. The resolution of\n the mapped rgb frame is the same as that of the depth image. @param[in] device The handle of the device on which to enable or disable mapping. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] bEnabled Set to true to enable the feature or false to disable the feature. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.