pub unsafe extern "C" fn Ps2_SetMapperEnabledRGBToDepth(
device: PsDeviceHandle,
sessionIndex: u32,
bEnabled: u8,
) -> PsReturnStatusExpand description
@brief Enables or disables mapping of the RGB image to depth space on the device. When enabled, PsGetFrame()\n
can be invoked passing ::PsMappedDepthFrame as the frame type, to get the RGB frame that is mapped to depth space. The resolution\n
of the mapped depth frame is the same as that of the RGB image.
@param[in] device The handle of the device on which to enable or disable mapping.
@param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information.
@param[in] bEnabled Set to true to enable the feature or false to disable the feature.
@return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.