pub unsafe extern "C" fn Ps2_SetSpatialFilterEnabled(
device: PsDeviceHandle,
sessionIndex: u32,
bEnabled: u8,
) -> PsReturnStatusExpand description
@brief Enables or disables the SpatialFilter feature.
@param[in] device The handle of the device on which to enable or disable the feature.
@param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information.
@param[in] bEnabled Set to true to enable the feature or false to disable the feature.
@return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.