scConvertDepthFrameToPointCloudVector

Function scConvertDepthFrameToPointCloudVector 

pub unsafe extern "C" fn scConvertDepthFrameToPointCloudVector(
    device: ScDeviceHandle,
    pDepthFrame: *const ScFrame,
    pWorldVector: *mut ScVector3f,
) -> ScStatus
@brief Converts the input Depth frame from depth coordinate space to world coordinate space on the device. Currently supported depth image types are SC_DEPTH_FRAME and SC_TRANSFORM_DEPTH_IMG_TO_COLOR_SENSOR_FRAME. @param[in] device The handle of the device on which to perform the operation. @param[in] pDepthFrame The depth frame. @param[out] pWorldVector Pointer to a buffer in which to output the converted x, y, and z values of the world coordinates, measured in millimeters. The length of pWorldVector must is (ScFrame.width * ScFrame.height). @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.