pub unsafe extern "C" fn scConvertDepthToPointCloud(
device: ScDeviceHandle,
pDepthVector: *mut ScDepthVector3,
pWorldVector: *mut ScVector3f,
pointCount: i32,
pSensorParam: *mut ScSensorIntrinsicParameters,
) -> ScStatusExpand description
@brief Converts the input points from depth coordinate space to world coordinate space. @param[in] device The handle of the device on which to perform the operation. @param[in] pDepthVector Pointer to a buffer containing the x, y, and z values of the depth coordinates to be converted. \n x and y are measured in pixels, where 0, 0 is located at the top left corner of the image. \n z is measured in millimeters, based on the ::ScPixelFormat depth frame. @param[out] pWorldVector Pointer to a buffer in which to output the converted x, y, and z values of the world coordinates, measured in millimeters. @param[in] pointCount The number of points to convert. @param[in] pSensorParam The intrinsic parameters for the depth sensor. See ::ScSensorIntrinsicParameters. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.