scExportParamInitFile

Function scExportParamInitFile 

pub unsafe extern "C" fn scExportParamInitFile(
    device: ScDeviceHandle,
    pfilePath: *mut c_char,
) -> ScStatus
@brief Export the parameter initialization file from the device. @param[in] device The handle of the device. @param[in] pfilePath Pointer to the path of parameter initialization file. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.