pub unsafe extern "C" fn scGetFrameRate(
device: ScDeviceHandle,
pValue: *mut i32,
) -> ScStatusExpand description
@brief Get the ToF frame rate. @param[in] device The handle of the device on which to get the framerate. @param[out] pValue The rate value. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.