scGetSpatialFilterEnabled

Function scGetSpatialFilterEnabled 

pub unsafe extern "C" fn scGetSpatialFilterEnabled(
    device: ScDeviceHandle,
    pEnabled: *mut u8,
) -> ScStatus
@brief Returns the Boolean value of whether the Spatial Filter feature is enabled or disabled. @param[in] device The handle of the device @param[out] pEnabled Pointer to a variable in which to store the returned Boolean value. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.