scGetTransformDepthImgToColorSensorEnabled

Function scGetTransformDepthImgToColorSensorEnabled 

pub unsafe extern "C" fn scGetTransformDepthImgToColorSensorEnabled(
    device: ScDeviceHandle,
    bEnabled: *mut u8,
) -> ScStatus
@brief Returns the Boolean value of whether the transformed of the depth image to color space feature is enabled or disabled. @param[in] device The handle of the device on which to enable or disable the feature. @param[out] bEnabled Pointer to a variable in which to store the returned Boolean value. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.