scImportParamInitFile

Function scImportParamInitFile 

pub unsafe extern "C" fn scImportParamInitFile(
    device: ScDeviceHandle,
    pfilePath: *mut c_char,
) -> ScStatus
@brief Import the parameter initialization file into the device and take effect after reboot the device. @param[in] device The handle of the device. @param[in] pfilePath Pointer to the path of parameter initialization file. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.