pub unsafe extern "C" fn scRestoreParamInitFile(
device: ScDeviceHandle,
) -> ScStatusExpand description
@brief Restore the parameter initialization file of the device. @param[in] device The handle of the device. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.