scSetDeviceSubnetMask

Function scSetDeviceSubnetMask 

pub unsafe extern "C" fn scSetDeviceSubnetMask(
    device: ScDeviceHandle,
    pMask: *const c_char,
    length: i32,
) -> ScStatus
@brief Set the subnet mask of the device in non-DHCP mode. The call takes effect after the device is restarted. @param[in] device The handle of the device. @param[in] pMask Pointer to a buffer in which to store the subnet mask address. the buffer default size is 16, and the last buffer set ‘\0’. @param[in] length The length of the buffer. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.