scSetFrameRate

Function scSetFrameRate 

pub unsafe extern "C" fn scSetFrameRate(
    device: ScDeviceHandle,
    value: i32,
) -> ScStatus
@brief Set the ToF frame rate.The interface takes a long time, about 500 ms. @param[in] device The handle of the device on which to set the framerate. @param[in] value The rate value. Different products have different maximum values. Please refer to the product specification. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.