scSetRealTimeSyncConfig

Function scSetRealTimeSyncConfig 

pub unsafe extern "C" fn scSetRealTimeSyncConfig(
    device: ScDeviceHandle,
    params: ScTimeSyncConfig,
) -> ScStatus
@brief Set the parameters for time sync, such as enable the NTP/PTP @param[in] device The handle of the device on which to enable or disable the feature. @param[in] params The parameters defined by ::ScTimeSyncConfig. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.