scSetSoftwareTriggerParameter

Function scSetSoftwareTriggerParameter 

pub unsafe extern "C" fn scSetSoftwareTriggerParameter(
    device: ScDeviceHandle,
    frameCount: u8,
) -> ScStatus
@brief Set the count of frame in SC_SOFTWARE_TRIGGER_MODE. The more frames there are, the better frame’s quality after algorithm processing @param[in] device The handle of the device on which to set the parameter @param[in] frameCount The count of frame, in range [1,10]. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.