scSetTransformColorImgToDepthSensorEnabled

Function scSetTransformColorImgToDepthSensorEnabled 

pub unsafe extern "C" fn scSetTransformColorImgToDepthSensorEnabled(
    device: ScDeviceHandle,
    bEnabled: u8,
) -> ScStatus
@brief Enables or disables transforms a color image into the geometry of the depth sensor. When enabled, scGetFrame() can\n be invoked passing ::ScTransformedColorFrame as the frame type for get a color image which each pixel matches the \n corresponding pixel coordinates of the depth sensor. The resolution of the transformed color frame is the same as that\n of the depth image. @param[in] device The handle of the device on which to enable or disable mapping. @param[in] bEnabled Set to true to enable the feature or false to disable the feature. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.