pub unsafe extern "C" fn scSetTransformDepthImgToColorSensorEnabled(
device: ScDeviceHandle,
bEnabled: u8,
) -> ScStatusExpand description
@brief Enables or disables transforms the depth map into the geometry of the color sensor. When enabled, scGetFrame() can\n
be invoked passing ::ScTransformedDepthFrame as the frame type for get a depth image which each pixel matches the \n
corresponding pixel coordinates of the color sensor. The resolution of the transformed depth frame is the same as that\n
of the color image.
@param[in] device The handle of the device on which to enable or disable mapping.
@param[in] bEnabled Set to true to enable the feature or false to disable the feature.
@return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.