pub unsafe extern "C" fn scTransformDepthPointToColorPoint(
device: ScDeviceHandle,
depthPoint: ScDepthVector3,
colorSize: ScVector2u16,
pPointInColor: *mut ScVector2u16,
) -> ScStatusExpand description
@brief Returns the point value of the frame that the mapping of the depth image to Color space. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] depthPoint The point in depth frame. @param[in] colorSize The size(x = w,y = h) of color frame. @param[out] pPointInColor The point in the color frame. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.