#[repr(C, packed(1))]pub struct ScFlyingPixelFilterParams {
pub threshold: i32,
pub enable: bool,
}Fields
threshold: i32!< Range in [1, 16]. The larger the value is, the more obvious the filtering effect is and the more points are filtered out.
enable: bool!< Whether to enable flying pixel filter.