#[repr(C, packed(1))]pub struct ScTimeFilterParams {
pub threshold: i32,
pub enable: bool,
}Fields
threshold: i32!< Range in [1, 6],The larger the value is, the more obvious the filtering effect is and The smaller the point cloud wobble.
enable: bool!< Whether to enable time filter.