PtrHotPlugStatusCallback

Type Alias PtrHotPlugStatusCallback 

pub type PtrHotPlugStatusCallback = Option<unsafe extern "C" fn(pInfo: *const ScDeviceInfo, state: c_int, pUserData: *mut c_void)>;
@brief Hot plug status callback function. @param[out] pInfo Return the info of the Device, See ::ScDeviceInfo. @param[out] state Hot plug status. 0:device added , 1:device removed. @param[out] pUserData Pointer to user data, which can be null.

Aliased Type

pub enum PtrHotPlugStatusCallback {
    None,
    Some(unsafe extern "C" fn(*const ScDeviceInfo, i32, *mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const ScDeviceInfo, i32, *mut c_void))

Some value of type T.