vzense_sys

Type Alias PtrHotPlugStatusCallback_

source
pub type PtrHotPlugStatusCallback_ = Option<unsafe extern "C" fn(pInfo: *const PsDeviceInfo, state: c_int, contex: *mut c_void)>;
@brief hotplug status callback function for c plus plus pInfo return the info of the Device, See ::PsDeviceInfo state 0:device added , 1:device removed contex pointer to the object of C++ class

Aliased Type

enum PtrHotPlugStatusCallback_ {
    None,
    Some(unsafe extern "C" fn(_: *const PsDeviceInfo, _: i32, _: *mut c_void)),
}

Variants

1.6.0

None

No value.

1.6.0

Some(unsafe extern "C" fn(_: *const PsDeviceInfo, _: i32, _: *mut c_void))

Some value of type T.