pub unsafe extern "C" fn Ps2_ConvertDepthFrameToWorldVector(
device: PsDeviceHandle,
sessionIndex: u32,
depthFrame: PsFrame,
pWorldVector: *mut PsVector3f,
) -> PsReturnStatusExpand description
@brief Converts the input Depth frame from depth coordinate space to world coordinate space on the device. @param[in] device The handle of the device on which to perform the operation. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] depthFrame The depth frame. @param[out] pWorldVector Pointer to a buffer in which to output the converted x, y, and z values of the world coordinates, measured in millimeters. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.