pub unsafe extern "C" fn Ps2_GetMappedPointDepthToRGB(
device: PsDeviceHandle,
sessionIndex: u32,
depthPoint: PsDepthVector3,
rgbSize: PsVector2u16,
pPosInRGB: *mut PsVector2u16,
) -> PsReturnStatusExpand description
@brief Returns the point value of the frame that the mapping of the depth image to RGB space. @param[in] device The handle of the device on which to enable or disable the feature. @param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information. @param[in] pointInDepth The point in depth frame. @param[in] rgbSize The size(x = w,y = h) of rgb frame.
@param[out] pPointInRGB The point in the rgb frame. @return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.