pub unsafe extern "C" fn Ps2_SetDataMode(
device: PsDeviceHandle,
sessionIndex: u32,
dataMode: PsDataMode,
) -> PsReturnStatusExpand description
@brief Sets the output data mode for the device specified by device.
@param[in] device The handle of the device for which to set the data mode.
@param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information.
@param[in] dataMode The output data mode. See ::PsDataMode for more information.
@return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.