pub unsafe extern "C" fn Ps2_SetPulseCount(
device: PsDeviceHandle,
sessionIndex: u32,
pulseCount: u16,
) -> PsReturnStatusExpand description
@brief Sets the pulse count for the device specified by device.
@param[in] device The handle of the device on which to set the pulse count.
@param[in] sessionIndex The index of the session. See ::Ps2_StartStream() & ::Ps2_StopStream() api for more information.
@param[in] pulseCount The pulse count value to set.For the range 3 and 4,the value is in the range [0,260],for the other range,the value is in the range [0,600].
@return ::PsRetOK if the function succeeded, or one of the error values defined by ::PsReturnStatus.