pub unsafe extern "C" fn scSetColorAECMaxExposureTime(
device: ScDeviceHandle,
exposureTime: i32,
) -> ScStatusExpand description
@brief Set the maximum exposure time of color sensor in automatic mode. The interface is used in automatic mode. @param[in] device The handle of the device on which to set the exposure time in microseconds. @param[in] exposureTime The exposure time. The value must be within the maximum exposure time of sensor. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.