pub unsafe extern "C" fn scSetColorPixelFormat(
device: ScDeviceHandle,
pixelFormat: ScPixelFormat,
) -> ScStatusExpand description
@brief Set the color image pixel format on the device specified by device. Currently only RGB and BGR formats are supported.
@param[in] device The handle of the device to set the pixel format.
@param[in] pixelFormat The color pixel format to use. Pass in one of the values defined by ::ScPixelFormat. Others cameras support only
SC_PIXEL_FORMAT_RGB_888_JPEG and SC_PIXEL_FORMAT_BGR_888_JPEG.
@return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.