pub unsafe extern "C" fn scSetDeviceIPAddr(
device: ScDeviceHandle,
ipAddr: *const c_char,
length: i32,
) -> ScStatusExpand description
@brief Set the IP address of the device in non-DHCP mode. The call takes effect after the device is restarted. @param[in] device The handle of the device. @param[in] ipAddr Pointer to a buffer in which to store the device IP address. the buffer default size is 16, and the last buffer set ‘\0’. @param[in] length The length of the buffer. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.