pub unsafe extern "C" fn scSetExposureControlMode(
device: ScDeviceHandle,
sensorType: ScSensorType,
controlMode: ScExposureControlMode,
) -> ScStatusExpand description
@brief Set the exposure mode of sensor. @param[in] device The handle of the device on which to set the exposure control mode. @param[in] sensorType The type of sensor (depth or color) from which to get parameter information. Pass in the applicable value defined by ::ScSensorType. @param[in] exposureType The exposure control mode. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.