pub unsafe extern "C" fn scSetWorkMode(
device: ScDeviceHandle,
mode: ScWorkMode,
) -> ScStatusExpand description
@brief Set the working mode of the camera. @param[in] device The handle of the device. @param[in] mode The work mode of camera. For ActiveMode, set the Time filter default true, for SlaveMode, set the Time filter default false. @return ::SC_OK If the function succeeded, or one of the error values defined by ::ScStatus.