pub type PtrHotPlugStatusCallback_ = Option<unsafe extern "C" fn(pInfo: *const PsDeviceInfo, state: c_int, contex: *mut c_void)>;Expand description
@brief hotplug status callback function for c plus plus pInfo return the info of the Device, See ::PsDeviceInfo state 0:device added , 1:device removed contex pointer to the object of C++ class
Aliased Type
enum PtrHotPlugStatusCallback_ {
None,
Some(unsafe extern "C" fn(_: *const PsDeviceInfo, _: i32, _: *mut c_void)),
}